@@ -6,10 +6,31 @@ from typing import Any, Dict, Optional
 import click
 
 from .click_common import command, format_output, EnumType
-from .device import Device, DeviceException
+from .device import Device, DeviceInfo, DeviceException
 
 _LOGGER = logging.getLogger(__name__)
 
+MODEL_HUMIDIFIER_V1 = 'zhimi.humidifier.v1'
+MODEL_HUMIDIFIER_CA1 = 'zhimi.humidifier.ca1'
+
+AVAILABLE_PROPERTIES_COMMON = [
+    'power',
+    'mode',
+    'temp_dec',
+    'humidity',
+    'buzzer',
+    'led_b',
+    'child_lock',
+    'limit_hum',
+    'use_time',
+    'hw_version',
+]
+
+AVAILABLE_PROPERTIES = {
+    MODEL_HUMIDIFIER_V1: AVAILABLE_PROPERTIES_COMMON + ['trans_level', 'button_pressed'],
+    MODEL_HUMIDIFIER_CA1: AVAILABLE_PROPERTIES_COMMON + ['speed', 'depth', 'dry'],
+}
+
 
 class AirHumidifierException(DeviceException):
     pass
@@ -20,6 +41,7 @@ class OperationMode(enum.Enum):
     Medium = 'medium'
     High = 'high'
     Auto = 'auto'
+    Strong = 'strong'
 
 
 class LedBrightness(enum.Enum):
@@ -31,7 +53,7 @@ class LedBrightness(enum.Enum):
 class AirHumidifierStatus:
     """Container for status reports from the air humidifier."""
 
-    def __init__(self, data: Dict[str, Any]) -> None:
+    def __init__(self, data: Dict[str, Any], device_info: DeviceInfo) -> None:
         """
         Response of a Air Humidifier (zhimi.humidifier.v1):
 
@@ -43,6 +65,7 @@ class AirHumidifierStatus:
         """
 
         self.data = data
+        self.device_info = device_info
 
     @property
     def power(self) -> str:
@@ -94,24 +117,64 @@ class AirHumidifierStatus:
         return self.data["limit_hum"]
 
     @property
-    def trans_level(self) -> int:
-        """The meaning of the property is unknown."""
-        return self.data["trans_level"]
+    def trans_level(self) -> Optional[int]:
+        """
+        The meaning of the property is unknown.
+
+        The property is used to determine the strong mode is enabled on old firmware.
+        """
+        if "trans_level" in self.data and self.data["trans_level"] is not None:
+            return self.data["trans_level"]
+        return None
+
+    @property
+    def strong_mode_enabled(self) -> bool:
+        if self.firmware_version_minor == 25:
+            if self.trans_level == 90:
+                return True
+
+        elif self.firmware_version_minor > 25:
+            return self.mode.value == "strong"
+
+        return False
+
+    @property
+    def firmware_version(self) -> str:
+        """Returns the fw_ver of miIO.info. For example 1.2.9_5033."""
+        return self.device_info.firmware_version
+
+    @property
+    def firmware_version_major(self) -> str:
+        major, _ = self.firmware_version.rsplit('_', 1)
+        return major
+
+    @property
+    def firmware_version_minor(self) -> int:
+        _, minor = self.firmware_version.rsplit('_', 1)
+        return int(minor)
 
     @property
     def speed(self) -> Optional[int]:
         """Current fan speed."""
-        return self.data["speed"]
+        if "speed" in self.data and self.data["speed"] is not None:
+            return self.data["speed"]
+        return None
 
     @property
     def depth(self) -> Optional[int]:
-        """Current depth."""
-        return self.data["depth"]
+        """The remaining amount of water in percent."""
+        if "depth" in self.data and self.data["depth"] is not None:
+            return self.data["depth"]
+        return None
 
     @property
     def dry(self) -> Optional[bool]:
-        """Return True if dry mode is on if available."""
-        if self.data["dry"] is not None:
+        """
+        Dry mode: The amount of water is not enough to continue to work for about 8 hours.
+
+        Return True if dry mode is on if available.
+        """
+        if "dry" in self.data and self.data["dry"] is not None:
             return self.data["dry"] == "on"
         return None
 
@@ -128,7 +191,9 @@ class AirHumidifierStatus:
     @property
     def button_pressed(self) -> Optional[str]:
         """Last pressed button."""
-        return self.data["button_pressed"]
+        if "button_pressed" in self.data and self.data["button_pressed"] is not None:
+            return self.data["button_pressed"]
+        return None
 
     def __repr__(self) -> str:
         s = "<AirHumidiferStatus power=%s, " \
@@ -145,7 +210,10 @@ class AirHumidifierStatus:
             "dry=%s, " \
             "use_time=%s, " \
             "hardware_version=%s, " \
-            "button_pressed=%s>" % \
+            "button_pressed=%s, " \
+            "strong_mode_enabled=%s, " \
+            "firmware_version_major=%s, " \
+            "firmware_version_minor=%s>" % \
             (self.power,
              self.mode,
              self.temperature,
@@ -160,7 +228,10 @@ class AirHumidifierStatus:
              self.dry,
              self.use_time,
              self.hardware_version,
-             self.button_pressed)
+             self.button_pressed,
+             self.strong_mode_enabled,
+             self.firmware_version_major,
+             self.firmware_version_minor)
         return s
 
     def __json__(self):
@@ -170,6 +241,18 @@ class AirHumidifierStatus:
 class AirHumidifier(Device):
     """Implementation of Xiaomi Mi Air Humidifier."""
 
+    def __init__(self, ip: str = None, token: str = None, start_id: int = 0,
+                 debug: int = 0, lazy_discover: bool = True,
+                 model: str = MODEL_HUMIDIFIER_V1) -> None:
+        super().__init__(ip, token, start_id, debug, lazy_discover)
+
+        if model in AVAILABLE_PROPERTIES:
+            self.model = model
+        else:
+            self.model = MODEL_HUMIDIFIER_V1
+
+        self.device_info = None
+
     @command(
         default_output=format_output(
             "",
@@ -193,26 +276,35 @@ class AirHumidifier(Device):
     def status(self) -> AirHumidifierStatus:
         """Retrieve properties."""
 
-        properties = ['power', 'mode', 'temp_dec', 'humidity', 'buzzer',
-                      'led_b', 'child_lock', 'limit_hum', 'trans_level',
-                      'speed', 'depth', 'dry', 'use_time', 'button_pressed',
-                      'hw_version', ]
+        if self.device_info is None:
+            self.device_info = self.info()
 
-        values = self.send(
-            "get_prop",
-            properties
-        )
+        properties = AVAILABLE_PROPERTIES[self.model]
+
+        # A single request is limited to 16 properties. Therefore the
+        # properties are divided into multiple requests
+        _props_per_request = 15
+
+        # The  CA1 is limited to a single property per request
+        if self.model == MODEL_HUMIDIFIER_CA1:
+            _props_per_request = 1
+
+        _props = properties.copy()
+        values = []
+        while _props:
+            values.extend(self.send("get_prop", _props[:_props_per_request]))
+            _props[:] = _props[_props_per_request:]
 
         properties_count = len(properties)
         values_count = len(values)
         if properties_count != values_count:
-            _LOGGER.debug(
+            _LOGGER.error(
                 "Count (%s) of requested properties does not match the "
                 "count (%s) of received values.",
                 properties_count, values_count)
 
         return AirHumidifierStatus(
-            defaultdict(lambda: None, zip(properties, values)))
+            defaultdict(lambda: None, zip(properties, values)), self.device_info)
 
     @command(
         default_output=format_output("Powering on"),
@@ -298,3 +390,10 @@ class AirHumidifier(Device):
             return self.send("set_dry", ["on"])
         else:
             return self.send("set_dry", ["off"])
+
+
+class AirHumidifierCA1(AirHumidifier):
+    def __init__(self, ip: str = None, token: str = None, start_id: int = 0,
+                 debug: int = 0, lazy_discover: bool = True) -> None:
+        super().__init__(ip, token, start_id, debug, lazy_discover,
+                         model=MODEL_HUMIDIFIER_CA1)
