@@ -61,10 +61,10 @@ class ChuangmiPlugStatus:
         return None
 
     @property
-    def load_power(self) -> Optional[int]:
+    def load_power(self) -> Optional[float]:
         """Current power load, if available."""
         if "load_power" in self.data and self.data["load_power"] is not None:
-            return self.data["load_power"]
+            return float(self.data["load_power"])
         return None
 
     @property
@@ -78,7 +78,7 @@ class ChuangmiPlugStatus:
         s = "<ChuangmiPlugStatus " \
             "power=%s, " \
             "usb_power=%s, " \
-            "temperature=%s" \
+            "temperature=%s, " \
             "load_power=%s, " \
             "wifi_led=%s>" % \
             (self.power,
@@ -131,47 +131,47 @@ class ChuangmiPlug(Device):
                 properties_count, values_count)
 
         if self.model == MODEL_CHUANGMI_PLUG_V3:
-            load_power = self.send("get_power", [])  # Response: [300]
+            load_power = self.send("get_power")  # Response: [300]
             if len(load_power) == 1:
                 properties.append('load_power')
-                values.append(load_power[0])
+                values.append(load_power[0] * 0.01)
 
         return ChuangmiPlugStatus(
             defaultdict(lambda: None, zip(properties, values)))
 
     @command(
-        default_output = format_output("Powering on"),
+        default_output=format_output("Powering on"),
     )
     def on(self):
         """Power on."""
         if self.model == MODEL_CHUANGMI_PLUG_V1:
-            return self.send("set_on", [])
+            return self.send("set_on")
 
         return self.send("set_power", ["on"])
 
     @command(
-        default_output = format_output("Powering off"),
+        default_output=format_output("Powering off"),
     )
     def off(self):
         """Power off."""
         if self.model == MODEL_CHUANGMI_PLUG_V1:
-            return self.send("set_off", [])
+            return self.send("set_off")
 
         return self.send("set_power", ["off"])
 
     @command(
-        default_output = format_output("Powering USB on"),
+        default_output=format_output("Powering USB on"),
     )
     def usb_on(self):
         """Power on."""
-        return self.send("set_usb_on", [])
+        return self.send("set_usb_on")
 
     @command(
-        default_output = format_output("Powering USB off"),
+        default_output=format_output("Powering USB off"),
     )
     def usb_off(self):
         """Power off."""
-        return self.send("set_usb_off", [])
+        return self.send("set_usb_off")
 
     @command(
         click.argument("wifi_led", type=bool),
