@@ -16,8 +16,8 @@ MODEL_PRESSURE1 = 'chunmi.cooker.press1'
 MODEL_PRESSURE2 = 'chunmi.cooker.press2'
 MODEL_NORMAL1 = 'chunmi.cooker.normal1'
 MODEL_NORMAL2 = 'chunmi.cooker.normal2'
-MODEL_NORMAL4 = 'chunmi.cooker.normal3'
-MODEL_NORMAL3 = 'chunmi.cooker.normal4'
+MODEL_NORMAL3 = 'chunmi.cooker.normal3'
+MODEL_NORMAL4 = 'chunmi.cooker.normal4'
 MODEL_NORMAL5 = 'chunmi.cooker.normal5'
 
 MODEL_PRESSURE = [MODEL_PRESSURE1, MODEL_PRESSURE2]
@@ -817,7 +817,7 @@ class Cooker(Device):
         The temperature is only available while cooking.
         Approx. six data points per minute.
         """
-        data = self.send('get_temp_history', [])
+        data = self.send('get_temp_history')
 
         return TemperatureHistory(data[0])
 
