@@ -1,8 +1,11 @@
 import warnings
+import click
 from enum import IntEnum
 from typing import Tuple, Optional
 
+from .click_common import command, format_output
 from .device import Device, DeviceException
+from .utils import int_to_rgb, rgb_to_int
 
 
 class YeelightException(DeviceException):
@@ -35,11 +38,7 @@ class YeelightStatus:
     def rgb(self) -> Optional[Tuple[int, int, int]]:
         """Return color in RGB if RGB mode is active."""
         if self.color_mode == YeelightMode.RGB:
-            rgb = int(self.data["rgb"])
-            blue = rgb & 0xff
-            green = (rgb >> 8) & 0xff
-            red = (rgb >> 16) & 0xff
-            return red, green, blue
+            return int_to_rgb(int(self.data["rgb"]))
         return None
 
     @property
@@ -108,6 +107,20 @@ class Yeelight(Device):
                       "for more complete support.", stacklevel=2)
         super().__init__(*args, **kwargs)
 
+    @command(
+        default_output=format_output(
+            "",
+            "Name: {result.name}\n"
+            "Power: {result.is_on}\n"
+            "Brightness: {result.brightness}\n"
+            "Color mode: {result.color_mode}\n"
+            "RGB: {result.rgb}\n"
+            "HSV: {result.hsv}\n"
+            "Temperature: {result.color_temp}\n"
+            "Developer mode: {result.developer_mode}\n"
+            "Update default on change: {result.save_state_on_change}\n"
+            "\n")
+    )
     def status(self) -> YeelightStatus:
         """Retrieve properties."""
         properties = [
@@ -130,7 +143,12 @@ class Yeelight(Device):
 
         return YeelightStatus(dict(zip(properties, values)))
 
-    def on(self):
+    @command(
+        click.option("--transition", type=int, required=False, default=0),
+        click.option("--mode", type=int, required=False, default=0),
+        default_output=format_output("Powering on"),
+    )
+    def on(self, transition=0, mode=0):
         """Power on."""
         """
         set_power ["on|off", "smooth", time_in_ms, mode]
@@ -142,48 +160,97 @@ class Yeelight(Device):
         4: color flow
         5: moonlight
         """
+        if transition > 0 or mode > 0:
+            return self.send("set_power", ["on", "smooth", transition, mode])
         return self.send("set_power", ["on"])
 
-    def off(self):
+    @command(
+        click.option("--transition", type=int, required=False, default=0),
+        default_output=format_output("Powering off"),
+    )
+    def off(self, transition=0):
         """Power off."""
+        if transition > 0:
+            return self.send("set_power", ["off", "smooth", transition])
         return self.send("set_power", ["off"])
 
-    def set_brightness(self, bright):
+    @command(
+        click.argument("level", type=int),
+        click.option("--transition", type=int, required=False, default=0),
+        default_output=format_output("Setting brightness to {level}")
+    )
+    def set_brightness(self, level, transition=0):
         """Set brightness."""
-        if bright < 0 or bright > 100:
-            raise YeelightException("Invalid brightness: %s" % bright)
-        return self.send("set_bright", [bright])
+        if level < 0 or level > 100:
+            raise YeelightException("Invalid brightness: %s" % level)
+        if transition > 0:
+            return self.send("set_bright", [level, "smooth", transition])
+        return self.send("set_bright", [level])
 
-    def set_color_temp(self, ct):
+    @command(
+        click.argument("level", type=int),
+        click.option("--transition", type=int, required=False, default=0),
+        default_output=format_output("Setting color temperature to {level}")
+    )
+    def set_color_temp(self, level, transition=500):
         """Set color temp in kelvin."""
-        if ct > 6500 or ct < 1700:
-            raise YeelightException("Invalid color temperature: %s" % ct)
-        return self.send("set_ct_abx", [ct, "smooth", 500])
+        if level > 6500 or level < 1700:
+            raise YeelightException("Invalid color temperature: %s" % level)
+        if transition > 0:
+            return self.send("set_ct_abx", [level, "smooth", transition])
+        else:
+            return self.send("set_ct_abx", [level])
 
-    def set_rgb(self, rgb):
-        """Set color in encoded RGB."""
-        return self.send("set_rgb", [rgb])
+    @command(
+        click.argument("rgb", default=[255] * 3, type=click.Tuple([int, int, int])),
+        default_output=format_output("Setting color to {rgb}")
+    )
+    def set_rgb(self, rgb: Tuple[int, int, int]):
+        """Set color in RGB."""
+        for color in rgb:
+            if color < 0 or color > 255:
+                raise YeelightException("Invalid color: %s" % color)
+
+        return self.send("set_rgb", [rgb_to_int(rgb)])
 
     def set_hsv(self, hsv):
         """Set color in HSV."""
         return self.send("set_hsv", [hsv])
 
+    @command(
+        click.argument("enable", type=bool),
+        default_output=format_output("Setting developer mode to {enable}")
+    )
     def set_developer_mode(self, enable: bool) -> bool:
         """Enable or disable the developer mode."""
         return self.send("set_ps", ["cfg_lan_ctrl", str(int(enable))])
 
+    @command(
+        click.argument("enable", type=bool),
+        default_output=format_output("Setting save state on change {enable}")
+    )
     def set_save_state_on_change(self, enable: bool) -> bool:
         """Enable or disable saving the state on changes."""
         return self.send("set_ps", ["cfg_save_state", str(int(enable))])
 
+    @command(
+        click.argument("name", type=bool),
+        default_output=format_output("Setting name to {enable}")
+    )
     def set_name(self, name: str) -> bool:
         """Set an internal name for the bulb."""
         return self.send("set_name", [name])
 
+    @command(
+        default_output=format_output("Toggling the bulb"),
+    )
     def toggle(self):
         """Toggle bulb state."""
         return self.send("toggle")
 
+    @command(
+        default_output=format_output("Setting current settings to default"),
+    )
     def set_default(self):
         """Set current state as default."""
         return self.send("set_default")
